package de.hdm_stuttgart.mi.sda1.sql2catalog;

import java.io.IOException;
import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.SQLException;

import javax.xml.parsers.ParserConfigurationException;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.jdom2.Element;
import org.jdom2.output.Format;
import org.jdom2.output.XMLOutputter;
import org.xml.sax.SAXException;

/**
 * A simple SAX parser demo
 * 
 */
public class Rdbms2Xml {
   private static final Logger log = LogManager.getLogger(Rdbms2Xml.class);

   /**
    * @param args
    *           Unused
    * @throws SAXException
    * @throws ParserConfigurationException
    * @throws IOException
    */
   public static void main(String[] args) throws ParserConfigurationException,
         SAXException, IOException {


      
      // Register Driver
      final String sqlDriverClassName = Messages.getString("Xml2Rdbms.jdbcDriverName"); 
      try {
         Class.forName(sqlDriverClassName);
      } catch (ClassNotFoundException e) {
         Helper.exitWithErrorMessage(Messages.getString("Xml2Rdbms.errMsgUnableRegisterDriverClass") + sqlDriverClassName + "'", 1);
      }


      // Opening a JDBC connection
      // 
      Connection conn = null;
      
      final String jdbcConnectionUrl = Messages.getString("Xml2Rdbms.jdbcUrl"); 
      final String userName = Messages.getString("Xml2Rdbms.jdbcUser"); 
      try {
         conn = DriverManager.getConnection(jdbcConnectionUrl, userName, Messages.getString("Xml2Rdbms.jdbcPasswd")); 
      } catch (SQLException e) {
         Helper.exitWithErrorMessage(Messages.getString("Xml2Rdbms.errMsgUnableToConnect") + userName + "' to '" + 
               jdbcConnectionUrl + "'", 1); 
      }
      
      RdbmsAccess rdbmsAccess = null;
      try {
         rdbmsAccess = new RdbmsAccess(conn);
      } catch (SQLException e) {
         Helper.exitWithErrorMessage(Messages.getString("Xml2Rdbms.errMsgUnableInitDataInsert"), 1); 
      }
      
      final Element catalogElement = new Element("catalog");
      try {
         rdbmsAccess.appendProducts(catalogElement);
      } catch (SQLException e) {
         Helper.exitWithErrorMessage("Unable to read database:" + e.getLocalizedMessage(), 1);
      }
      
      // Write XML content to standard output
      XMLOutputter outputter = new XMLOutputter(Format.getPrettyFormat());
      outputter.output(catalogElement, System.out);
   }
   
}
